#include "DSC-100.h"
#include "SDL.h"

extern SDL_Surface *screen;

void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel);

static unsigned char table_rgb[16 * 3] = {
	0x00, 0x00, 0x00,
	0xff, 0x00, 0x00,
	0x00, 0xff, 0x00,
	0xff, 0xff, 0x00,
	0x00, 0x00, 0xff,
	0xff, 0x00, 0xff,
	0x00, 0xff, 0xff,
	0xff, 0xff, 0xff,
	0xc6, 0xc6, 0xc6,
	0x84, 0x00, 0x00,
	0x00, 0x84, 0x00,
	0x84, 0x84, 0x00,
	0x00, 0x00, 0x84,
	0x84, 0x00, 0x84,
	0x3a, 0x6e, 0xa5,
	0x84, 0x84, 0x84
};

int color_table[16];

void init_vram(unsigned char *mem)
{
	int x, y;
	int i;

	for(i = 0; i < 16; i++) {
		color_table[i] = ((int)(((char)(table_rgb[i * 3 + 0]) | ((short)(table_rgb[i * 3 + 1]) << 8)) | (((int)(char)(table_rgb[i * 3 + 2])) << 16)));
	}

	for(y = 0; y < YSIZE; y++) {
		for(x = 0; x < XSIZE; x++) {
			mem[VRAM + (y * XSIZE + x)] = 0;
		}
	}
}

void reflesh_vram(unsigned char *mem)
{
	int x, y;

	for(y = 0; y < YSIZE; y++) {
		for(x = 0; x < XSIZE; x++) {
			if(mem[VRAM + (y * XSIZE + x)] != 0) {
				putpixel(screen, x, y, color_table[mem[VRAM + (y * XSIZE + x)]] & 0x00ffffff);
			}
		}
	}
}

void putpixel(SDL_Surface *surface, int x, int y, Uint32 pixel) 
{ 
    int bpp=surface->format->BytesPerPixel; 
    Uint8 *p=(Uint8 *)surface->pixels + y * surface->pitch + x * bpp; 

    switch(bpp){ 
    case 1: 
        *p=pixel; 
        break; 

    case 2: 
        *(Uint16 *)p=pixel; 
    break; 

    case 3: 
        if(SDL_BYTEORDER == SDL_BIG_ENDIAN){ 
            p[0]=(pixel>>16) & 0xff; 
            p[1]=(pixel>>8) & 0xff; 
            p[2]=pixel & 0xff; 
        } else { 
            p[0]=pixel & 0xff; 
            p[1]=(pixel>>8) & 0xff; 
            p[2]=(pixel>>16) & 0xff; 
        } 
        break; 

    case 4: 
        *(Uint32 *)p=pixel; 
        break; 
    } 
} 